==> lxqt-panel-2.1.1.tar.xz: lxqt-panel-2.1.1/plugin-fancymenu/translations/fancymenu_fi.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fi">
<context>
    <name>LXQtFancyMenu</name>
    <message>
        <location filename="../lxqtfancymenu.cpp" line="93"/>
        <source>Show/hide main menu</source>
        <translation>Näytä/piilota päävalikko</translation>
    </message>
</context>
<context>
    <name>LXQtFancyMenuAppMapStrings</name>
    <message>
        <location filename="../lxqtfancymenuappmap.cpp" line="49"/>
        <source>Favorites</source>
        <translation>Suosikit</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuappmap.cpp" line="56"/>
        <source>All Applications</source>
        <translation>Kaikki sovellukset</translation>
    </message>
</context>
<context>
    <name>LXQtFancyMenuConfiguration</name>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="14"/>
        <source>Fancy Menu Settings</source>
        <translation>Hienon valikon asetukset</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>Yleiset</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="35"/>
        <source>Icon:</source>
        <translation>Kuvake:</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="59"/>
        <source>Button text:</source>
        <translation>Painikkeen teksti:</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="76"/>
        <source>Custom font size:</source>
        <translation>Oma fonttikoko:</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="86"/>
        <source> pt</source>
        <translation> pt</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="99"/>
        <source>Auto-select after:</source>
        <translation>Automaattinen valinta viiveellä:</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="109"/>
        <source> ms</source>
        <translation> ms</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="134"/>
        <source>Menu file</source>
        <translation>Valikkotiedosto</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="140"/>
        <source>Menu file:</source>
        <translation>Valikkotiedosto:</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="156"/>
        <source>Keyboard Shortcut</source>
        <translation>Pikanäppäin</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="175"/>
        <source>Click the button to record shortcut:</source>
        <translation>Napsauta painiketta nauhoittaaksesi pikanäppäimen:</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="185"/>
        <source>Search</source>
        <translation>Haku</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="191"/>
        <source>Clear search upon showing menu</source>
        <translation>Tyhjennä hakukenttä, kun päävalikko avataan</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="201"/>
        <source>Layout</source>
        <translation>Asettelu</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="210"/>
        <source>Buttons row position</source>
        <translation>Painikerivin sijainti</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="217"/>
        <source>Categories position</source>
        <translation>Luokkien sijainti</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="81"/>
        <source>Reset</source>
        <translation>Palauta</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="111"/>
        <source>Bottom</source>
        <translation>Alhaalla</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="112"/>
        <source>Top</source>
        <translation>Ylhäällä</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="117"/>
        <source>Left</source>
        <translation>Vasemmalla</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="118"/>
        <source>Right</source>
        <translation>Oikealla</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="179"/>
        <source>Choose icon file</source>
        <translation>Valitse kuvake</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="181"/>
        <source>Images (*.svg *.png)</source>
        <translation>Kuvat (*.svg *.png)</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="193"/>
        <source>Choose menu file</source>
        <translation>Valitse valikkotiedosto</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="195"/>
        <source>Menu files (*.menu)</source>
        <translation>Valikkotiedostot (*.menu)</translation>
    </message>
</context>
<context>
    <name>LXQtFancyMenuWindow</name>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="155"/>
        <source>Search...</source>
        <translation>Etsi...</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="161"/>
        <source>LXQt Configuration Center</source>
        <translation>LXQt:n asetuskeskus</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="167"/>
        <source>Leave</source>
        <translation>Poistu</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="173"/>
        <source>About LXQt</source>
        <translation>Tietoja LQXt:stä</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="191"/>
        <source>Add your favorites by right clicking items from categories.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="357"/>
        <source>Add to desktop</source>
        <translation>Lisää työpöydälle</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="365"/>
        <source>Question</source>
        <translation>Kysymys</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="366"/>
        <source>A file with the same name already exists.
Do you want to overwrite it?</source>
        <translation>Samanniminen tiedosto on jo olemassa.
Haluatko korvata sen?</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="372"/>
        <source>Warning</source>
        <translation>Varoitus</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="373"/>
        <source>The file cannot be overwritten.</source>
        <translation>Tiedostoa ei voida korvata.</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="380"/>
        <source>Copy</source>
        <translation>Kopioi</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="393"/>
        <source>Remove from Favorites</source>
        <translation>Poista suosikeista</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="400"/>
        <source>Add to Favorites</source>
        <translation>Lisää suosikkeihin</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="716"/>
        <source>No Executable</source>
        <translation>Ei ohjelmatiedosto(a)</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="717"/>
        <source>Cannot find &lt;b&gt;%1&lt;/b&gt; executable.</source>
        <translation>Ohjelmatiedostoa &lt;b&gt;%1&lt;/b&gt; ei löydy.</translation>
    </message>
</context>
</TS>

==> lxqt-panel_2.1.4.orig.tar.xz: lxqt-panel-2.1.4/plugin-fancymenu/translations/fancymenu_fi.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fi">
<context>
    <name>LXQtFancyMenu</name>
    <message>
        <location filename="../lxqtfancymenu.cpp" line="93"/>
        <source>Show/hide main menu</source>
        <translation>Näytä/piilota päävalikko</translation>
    </message>
</context>
<context>
    <name>LXQtFancyMenuAppMapStrings</name>
    <message>
        <location filename="../lxqtfancymenuappmap.cpp" line="49"/>
        <source>Favorites</source>
        <translation>Suosikit</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuappmap.cpp" line="56"/>
        <source>All Applications</source>
        <translation>Kaikki sovellukset</translation>
    </message>
</context>
<context>
    <name>LXQtFancyMenuConfiguration</name>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="14"/>
        <source>Fancy Menu Settings</source>
        <translation>Hienon valikon asetukset</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>Yleiset</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="35"/>
        <source>Icon:</source>
        <translation>Kuvake:</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="59"/>
        <source>Button text:</source>
        <translation>Painikkeen teksti:</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="76"/>
        <source>Custom font size:</source>
        <translation>Oma fonttikoko:</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="86"/>
        <source> pt</source>
        <translation> pt</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="99"/>
        <source>Auto-select after:</source>
        <translation>Automaattinen valinta viiveellä:</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="109"/>
        <source> ms</source>
        <translation> ms</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="134"/>
        <source>Menu file</source>
        <translation>Valikkotiedosto</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="140"/>
        <source>Menu file:</source>
        <translation>Valikkotiedosto:</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="156"/>
        <source>Keyboard Shortcut</source>
        <translation>Pikanäppäin</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="175"/>
        <source>Click the button to record shortcut:</source>
        <translation>Napsauta painiketta nauhoittaaksesi pikanäppäimen:</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="185"/>
        <source>Search</source>
        <translation>Haku</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="191"/>
        <source>Clear search upon showing menu</source>
        <translation>Tyhjennä hakukenttä, kun päävalikko avataan</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="201"/>
        <source>Layout</source>
        <translation>Asettelu</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="210"/>
        <source>Buttons row position</source>
        <translation>Painikerivin sijainti</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="217"/>
        <source>Categories position</source>
        <translation>Luokkien sijainti</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="81"/>
        <source>Reset</source>
        <translation>Palauta</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="111"/>
        <source>Bottom</source>
        <translation>Alhaalla</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="112"/>
        <source>Top</source>
        <translation>Ylhäällä</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="117"/>
        <source>Left</source>
        <translation>Vasemmalla</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="118"/>
        <source>Right</source>
        <translation>Oikealla</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="179"/>
        <source>Choose icon file</source>
        <translation>Valitse kuvake</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="181"/>
        <source>Images (*.svg *.png)</source>
        <translation>Kuvat (*.svg *.png)</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="193"/>
        <source>Choose menu file</source>
        <translation>Valitse valikkotiedosto</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="195"/>
        <source>Menu files (*.menu)</source>
        <translation>Valikkotiedostot (*.menu)</translation>
    </message>
</context>
<context>
    <name>LXQtFancyMenuWindow</name>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="155"/>
        <source>Search...</source>
        <translation>Etsi...</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="161"/>
        <source>LXQt Configuration Center</source>
        <translation>LXQt:n asetuskeskus</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="167"/>
        <source>Leave</source>
        <translation>Poistu</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="173"/>
        <source>About LXQt</source>
        <translation>Tietoja LQXt:stä</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="191"/>
        <source>Add your favorites by right clicking items from categories.</source>
        <translation>Lisää luokista suosikkeihisi hiiren oikealla.</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="357"/>
        <source>Add to desktop</source>
        <translation>Lisää työpöydälle</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="365"/>
        <source>Question</source>
        <translation>Kysymys</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="366"/>
        <source>A file with the same name already exists.
Do you want to overwrite it?</source>
        <translation>Samanniminen tiedosto on jo olemassa.
Haluatko korvata sen?</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="372"/>
        <source>Warning</source>
        <translation>Varoitus</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="373"/>
        <source>The file cannot be overwritten.</source>
        <translation>Tiedostoa ei voida korvata.</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="380"/>
        <source>Copy</source>
        <translation>Kopioi</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="393"/>
        <source>Remove from Favorites</source>
        <translation>Poista suosikeista</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="400"/>
        <source>Add to Favorites</source>
        <translation>Lisää suosikkeihin</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="716"/>
        <source>No Executable</source>
        <translation>Ei ohjelmatiedosto(a)</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="717"/>
        <source>Cannot find &lt;b&gt;%1&lt;/b&gt; executable.</source>
        <translation>Ohjelmatiedostoa &lt;b&gt;%1&lt;/b&gt; ei löydy.</translation>
    </message>
</context>
</TS>
